@@ -9,8 +9,6 @@ class R10K::Module::Git < R10K::Module::Base
 
   def self.implement?(name, args)
     args.has_key?(:git) || args[:type].to_s == 'git'
-  rescue
-    false
   end
 
   # Will be called if self.implement? above returns true. Will return
@@ -48,6 +46,11 @@ class R10K::Module::Git < R10K::Module::Base
   #   @return [String]
   attr_reader :default_override_ref
 
+  # @!attribute[r] remote
+  #   @api private
+  #   @return [String]
+  attr_reader :remote
+
   include R10K::Util::Setopts
 
   def initialize(title, dirname, opts, environment=nil)
@@ -69,7 +72,7 @@ class R10K::Module::Git < R10K::Module::Base
       :default_branch_override => :default_override_ref,
     }, :raise_on_unhandled => false)
 
-    force = @overrides.dig(:modules, :force)
+    force = @overrides[:force]
     @force = force == false ? false : true
 
     @desired_ref ||= 'master'
@@ -102,7 +105,7 @@ class R10K::Module::Git < R10K::Module::Base
   def sync(opts={})
     force = opts[:force] || @force
     if should_sync?
-      updated = @repo.sync(version, force)
+      updated = @repo.sync(version, force, @exclude_spec)
     else
       updated = false
     end
